@@ -73,7 +73,7 @@ class BaseHandler(tornado.web.RequestHandler):
         for domain in domains:
             if domain.startswith('*') and referer.endswith(domain[1:]):
                 return True
-            elif referer.endswith(domain):
+            elif referer == domain:
                 return True
 
         if raise_error:
@@ -153,7 +153,7 @@ class BaseHandler(tornado.web.RequestHandler):
             if value:
                 kwargs[key] = value[0] if len(value) == 1 else value
 
-        for key in ['page', 'count', 'order']:
+        for key in ['page', 'size', 'order']:
             if kwargs.get(key) is not None:
                 kwargs[key] = int(kwargs[key])
 
@@ -164,12 +164,11 @@ class BaseHandler(tornado.web.RequestHandler):
         ret = urllib.parse.urlparse(self.request.uri)
         query = urllib.parse.parse_qs(ret.query)
         query.update(kwargs)
-        uri = urllib.parse.urlunparse((ret.scheme, ret.netloc, ret.path, ret.params,
+        return urllib.parse.urlunparse((ret.scheme, ret.netloc, ret.path, ret.params,
                                        urllib.parse.urlencode(query, doseq=True), ret.fragment))
-        return uri
 
     def filter(self, query, include=[], exclude=[]):
-        exclude = list(set(exclude) | set(['page', 'count', 'sort', 'order', 'f']))
+        exclude = list(set(exclude) | set(['page', 'size', 'sort', 'order', 'f']))
         if include:
             query = dict(filter(lambda x: x[0] in include or x[0].startswith('$'), query.items()))
         query = dict(filter(lambda x: x[0] not in exclude, query.items()))
@@ -203,7 +202,7 @@ class BaseHandler(tornado.web.RequestHandler):
 
     async def _post_query(self, cursor):
         self.args.total = await cursor.count()
-        self.args.pages = int(math.ceil(self.args.total / float(self.args.count)))
+        self.args.pages = int(math.ceil(self.args.total / float(self.args.size)))
         return await cursor.to_list()
 
     def query(self, collection, query=None, projection=None, db=None, include=[], exclude=[], schema=None):
@@ -217,18 +216,18 @@ class BaseHandler(tornado.web.RequestHandler):
             projection = {k: 1 for k in projection}
         cursor = db[collection].find(query, projection)
 
-        self.args.setdefault('order', - 1)
+        self.args.setdefault('order', -1)
         self.args.setdefault('page', 1)
-        self.args.setdefault('count', 20)
+        self.args.setdefault('size', 20)
         if self.args.sort:
             cursor = cursor.sort(self.args.sort, self.args.order)
 
         self.logger.info(f'{db.name}.{collection} query: {query}, sort: {self.args.sort}')
-        cursor = cursor.skip((self.args.page - 1) * self.args.count).limit(self.args.count)
+        cursor = cursor.skip((self.args.page - 1) * self.args.size).limit(self.args.size)
 
         if isinstance(db, Motor):
             return self._post_query(cursor)
         else:
             self.args.total = cursor.count()
-            self.args.pages = int(math.ceil(self.args.total / float(self.args.count)))
+            self.args.pages = int(math.ceil(self.args.total / float(self.args.size)))
             return list(cursor)
