@@ -26,7 +26,7 @@ from .http_utils import Chrome
 from .http_utils import patch_connection_pool
 from .http_utils import Request
 from .http_utils import Response
-from .ip_region import Ip2Region
+from .ip2region import Ip2Region
 from .log_utils import Logger
 from .log_utils import WatchedFileHandler
 from .processor import Processor
