@@ -5,20 +5,19 @@ Author: zhangkai
 Email: zhangkai@cmcm.com
 Last modified: 2018-01-05 11:24:17
 '''
-import asyncio
+
 import os
 import re
-import time
 from urllib.parse import parse_qs
 from urllib.parse import quote_plus
 from urllib.parse import unquote_plus
+from dbutils.pooled_db import PooledDB
 
 import aiomysql
 import aredis
 import pymongo
 import pymysql
 import redis
-from aiomysql.connection import Connection
 from motor import core
 from motor.docstrings import get_database_doc
 from motor.frameworks import asyncio as asyncio_framework
@@ -40,7 +39,7 @@ def parse_uri(uri):
         (?P<schema>[\w\+]+)://
         (?:
             (?P<user>[^:/]*)
-            (?::(?P<passwd>[^/]*))?
+            (?::(?P<password>[^/]*))?
         @)?
         (?:
             (?P<host>[^/:]*)
@@ -309,7 +308,7 @@ class AioRedis(aredis.StrictRedis):
 
 class Mysql:
 
-    def __init__(self, time_zone='+08:00', max_idle_time=7 * 3600, charset='utf8',
+    def __init__(self, time_zone='+08:00', max_idle_time=3600, charset='utf8',
                  sql_mode='TRADITIONAL', autocommit=True, **kwargs):
         if any([key in kwargs for key in ['host', 'port', 'password']]):
             host = kwargs.pop('host', 'localhost')
@@ -326,63 +325,52 @@ class Mysql:
 
         kwargs.pop('schema', None)
         init_command = f'SET time_zone = "{time_zone}"'
-        self._args = dict(charset=charset, init_command=init_command,
-                          sql_mode=sql_mode, autocommit=autocommit, **kwargs)
-        self._conn = None
         self._pool = None
-        self._max_idle_time = max_idle_time
-        self._last_use_time = time.time()
+        self._kwargs = dict(charset=charset, init_command=init_command,
+                            sql_mode=sql_mode, autocommit=autocommit, **kwargs)
+
+    def cursor(self, cursorclass=pymysql.cursors.DictCursor):
+        if self._pool is None:
+            self._pool = PooledDB(pymysql, maxcached=10, **self._kwargs)
+        return self._pool.connection().cursor(cursorclass)
 
     def __del__(self):
         self.close()
 
     def close(self):
-        if getattr(self, "_conn", None) is not None:
-            self._conn.close()
-            self._conn = None
-
-    def reconnect(self):
-        self.close()
-        self._conn = pymysql.connect(**self._args)
-
-    def _ensure_connected(self):
-        if self._conn is None or (time.time() - self._last_use_time > self._max_idle_time):
-            self.reconnect()
-        self._last_use_time = time.time()
+        if self._pool is not None:
+            self._pool.close()
+            self._pool = None
 
     def iter(self, sql, *args):
-        self._ensure_connected()
-        cursor = self._conn.cursor(pymysql.cursors.SSCursor)
+        cursor = self.cursor(pymysql.cursors.SSDictCursor)
         try:
             cursor.execute(sql, args)
-            column_names = [d[0] for d in cursor.description]
-            for row in cursor:
-                yield Dict(zip(column_names, row))
+            for row in cursor.fetchall_unbuffered():
+                yield Dict(row)
         finally:
             cursor.close()
 
     def query(self, sql, *args):
-        self._ensure_connected()
-        cursor = self._conn.cursor()
+        cursor = self.cursor()
         try:
             cursor.execute(sql, args)
-            column_names = [d[0] for d in cursor.description]
-            return [Dict(zip(column_names, row)) for row in cursor]
+            rows = cursor.fetchall()
+            return [Dict(row) for row in rows]
         finally:
             cursor.close()
 
     def get(self, sql, *args):
-        rows = self.query(sql, *args)
-        if not rows:
-            return None
-        elif len(rows) > 1:
-            raise Exception("Multiple rows returned for Database.get() query")
-        else:
-            return rows[0]
+        cursor = self.cursor()
+        try:
+            cursor.execute(sql, args)
+            row = cursor.fetchone()
+            return Dict(row)
+        finally:
+            cursor.close()
 
     def execute(self, sql, *args):
-        self._ensure_connected()
-        cursor = self._conn.cursor()
+        cursor = self.cursor()
         try:
             cursor.execute(sql, args)
             return cursor.lastrowid
@@ -390,79 +378,56 @@ class Mysql:
             cursor.close()
 
     def executemany(self, sql, args):
-        self._ensure_connected()
-        cursor = self._conn.cursor()
+        cursor = self.cursor()
         try:
             return cursor.executemany(sql, args)
         finally:
             cursor.close()
 
 
-async def _read_bytes(self, num_bytes):
-    try:
-        data = await self._reader.readexactly(num_bytes)
-    except asyncio.exceptions.IncompleteReadError as e:
-        msg = "Lost connection to MySQL server during query"
-        raise pymysql.OperationalError(2013, msg) from e
-    except (IOError, OSError) as e:
-        msg = "Lost connection to MySQL server during query (%s)" % (e,)
-        raise pymysql.OperationalError(2013, msg) from e
-    return data
-
-Connection._read_bytes = _read_bytes
-
-
 class AioMysql(Mysql):
 
+    async def cursor(self, cursorclass=aiomysql.cursors.DictCursor):
+        if self._pool is None:
+            self._pool = await aiomysql.create_pool(minsize=0, maxsize=10, **self._kwargs)
+            self._conn = await self._pool.acquire()
+        return await self._conn.cursor(cursorclass)
+
     async def close(self):
-        if getattr(self, "_pool", None) is not None:
+        if self._pool is not None:
             self._pool.close()
             await self._pool.wait_closed()
-
-    async def reconnect(self):
-        await self.close()
-        self._pool = await aiomysql.create_pool(minsize=5, maxsize=10, **self._args)
-
-    async def _ensure_connected(self):
-        if self._pool is None or (time.time() - self._last_use_time > self._max_idle_time):
-            await self.reconnect()
-        self._last_use_time = time.time()
-        self._conn = await self._pool.acquire()
+            self._pool = None
 
     async def iter(self, sql, *args):
-        await self._ensure_connected()
-        cursor = await self._conn.cursor(aiomysql.cursors.SSCursor)
+        cursor = await self.cursor(aiomysql.cursors.SSDictCursor)
         try:
             await cursor.execute(sql, args)
-            column_names = [d[0] for d in cursor.description]
             async for row in cursor:
-                yield Dict(zip(column_names, row))
+                yield Dict(row)
         finally:
             await cursor.close()
 
     async def query(self, sql, *args):
-        await self._ensure_connected()
-        cursor = await self._conn.cursor()
+        cursor = await self.cursor()
         try:
             await cursor.execute(sql, args)
             rows = await cursor.fetchall()
-            column_names = [d[0] for d in cursor.description]
-            return [Dict(zip(column_names, row)) for row in rows]
+            return [Dict(row) for row in rows]
         finally:
             await cursor.close()
 
     async def get(self, sql, *args):
-        rows = await self.query(sql, *args)
-        if not rows:
-            return None
-        elif len(rows) > 1:
-            raise Exception("Multiple rows returned for Database.get() query")
-        else:
-            return rows[0]
+        cursor = await self.cursor()
+        try:
+            await cursor.execute(sql, args)
+            row = await cursor.fetchone()
+            return Dict(row)
+        finally:
+            await cursor.close()
 
     async def execute(self, sql, *args):
-        await self._ensure_connected()
-        cursor = await self._conn.cursor()
+        cursor = await self.cursor()
         try:
             await cursor.execute(sql, args)
             return cursor._lastrowid
@@ -470,8 +435,7 @@ class AioMysql(Mysql):
             await cursor.close()
 
     async def executemany(self, sql, args):
-        await self._ensure_connected()
-        cursor = await self._conn.cursor()
+        cursor = await self.cursor()
         try:
             return await cursor.executemany(sql, args)
         finally:
