@@ -4,6 +4,7 @@
 Author: zhangkai
 Last modified: 2019-11-12 16:04:04
 '''
+import asyncio
 import copy
 import functools
 import logging
@@ -42,36 +43,36 @@ def timeit(func):
 
 
 @smart_decorator
-def retry(func, count=2, raise_error=False):
+def retry(func, count=2, sleep=0, raise_error=False):
     logger = logging.getLogger()
 
     @functools.wraps(func)
     def wrapper(*args, **kwargs):
         for i in range(count):
             try:
-                _kwargs = copy.deepcopy(kwargs)
-                return func(*args, **_kwargs)
+                return func(*args, **copy.deepcopy(kwargs))
             except Exception as e:
                 logger.exception(f'{func.__name__}: {e}, retry: {i + 1}')
+                time.sleep(sleep)
                 if raise_error and i == count - 1:
                     raise
     return wrapper
 
 
 @smart_decorator
-def aioretry(func, count=2, raise_error=False):
+def aioretry(func, count=2, sleep=0, raise_error=False):
     logger = logging.getLogger()
 
     @functools.wraps(func)
     async def wrapper(*args, **kwargs):
         for i in range(count):
             try:
-                _kwargs = copy.deepcopy(kwargs)
-                return await func(*args, **_kwargs)
+                return await func(*args, **copy.deepcopy(kwargs))
             except GeneratorExit:
                 raise
             except Exception as e:
                 logger.exception(f'{func.__name__}: {e}, retry: {i + 1}')
+                await asyncio.sleep(sleep)
                 if raise_error and i == count - 1:
                     raise
     return wrapper
