@@ -79,16 +79,15 @@ class Email(EmailBase):
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.client = smtplib.SMTP()
+        if self.use_tls:
+            self.client = smtplib.SMTP_SSL(self.smtp, 465)
+        else:
+            self.client = smtplib.SMTP(self.smtp)
         # self.client = smtplib.SMTP('localhost')
         # self.sender = self.client.local_hostname
 
     def send(self, *args, **kwargs):
         msg = self.pack(*args, **kwargs)
-        if self.use_tls:
-            self.client.connect(self.smtp, port=465)
-        else:
-            self.client.connect(self.smtp)
         self.client.docmd('ehlo', self.smtp)
         self.client.login(self.user, self.pwd)
         self.client.send_message(msg)
