@@ -65,6 +65,7 @@ from .utils import to_bytes
 from .utils import to_str
 from .utils import tqdm
 
+
 logging.getLogger("requests").setLevel(logging.WARNING)
 
 __all__ = ['Response', 'Request', 'Chrome']
@@ -374,7 +375,7 @@ class BaseRequest(metaclass=RequestMeta):
         if shards > 1:
             url, kwargs = self._prepare(url, kwargs)
             kwargs['headers']['Range'] = 'bytes=0-0'
-            resp = self._request(url, **kwargs)
+            resp = self.request(url, **kwargs)
             filesize = int(resp.headers['Content-Range'].split('/')[-1])
             lock = threading.Lock()
             filename.parent.mkdir(parents=True, exist_ok=True)
@@ -389,7 +390,7 @@ class BaseRequest(metaclass=RequestMeta):
                 executor.map(func, *args)
             fp.close()
         else:
-            resp = self._request(url, **kwargs)
+            resp = self.request(url, **kwargs)
             if resp.code == 200:
                 filename.parent.mkdir(parents=True, exist_ok=True)
                 filename.write_bytes(resp.body)
@@ -795,9 +796,8 @@ class TornadoClient(Pycurl):
     async def _request(self, url, **kwargs):
         url, kwargs = self._prepare(url, kwargs)
         curl_callback = partial(self._curl_setup, url=url, **kwargs)
-        resp = Response(await self.http.fetch(url,
-                                              raise_error=False,
-                                              prepare_curl_callback=curl_callback))
+        resp = await self.http.fetch(url, raise_error=False, prepare_curl_callback=curl_callback)
+        resp = Response(resp)
         self._finish(kwargs)
         self.save_cookie(resp)
         return resp
@@ -807,7 +807,7 @@ class TornadoClient(Pycurl):
         if shards > 1:
             url, kwargs = self._prepare(url, kwargs)
             kwargs['headers']['Range'] = 'bytes=0-0'
-            resp = await self._request(url, **kwargs)
+            resp = await self.request(url, **kwargs)
             filesize = int(resp.headers['Content-Range'].split('/')[-1])
             block = int(math.ceil(filesize / shards))
             futures = []
@@ -816,7 +816,7 @@ class TornadoClient(Pycurl):
                 end = min(block * (i + 1), filesize) - 1
                 _kwargs = copy.deepcopy(kwargs)
                 _kwargs['headers']['Range'] = f'bytes={start}-{end}'
-                futures.append(self._request(url, **_kwargs))
+                futures.append(self.request(url, **_kwargs))
             resps = await asyncio.gather(*futures)
             filename.parent.mkdir(parents=True, exist_ok=True)
             with open(filename, 'wb') as fp:
@@ -824,7 +824,7 @@ class TornadoClient(Pycurl):
                     if resp.code == 206:
                         fp.write(resp.body)
         else:
-            resp = await self._request(url, **kwargs)
+            resp = await self.request(url, **kwargs)
             if resp.code == 200:
                 filename.parent.mkdir(parents=True, exist_ok=True)
                 filename.write_bytes(resp.body)
